From fbe76102e941b9f1edaf236788e42678f05fdf9a Mon Sep 17 00:00:00 2001
From: Daniel Wilhelm
Date: Fri, 18 Apr 2014 17:08:06 +0200
Subject: 3.9
---
Application.cpp | 70 +-
Application.h | 2 +-
BUILD/Changelog.txt | 19 +
BUILD/FreeFileSync.chm | Bin 374528 -> 376650 bytes
BUILD/Help/Table of Contents.hhc | 2 +-
BUILD/Help/html/Features.html | 8 +-
BUILD/Help/html/Unbenannt 1.odf | Bin 0 -> 4975 bytes
BUILD/Help/html/advanced/Batch Scripting.html | 14 +-
BUILD/Help/html/advanced/DragDrop.html | 8 +-
BUILD/Help/html/advanced/ExcludeSubfolder.html | 80 +-
BUILD/Help/html/advanced/TimeStamped.html | 29 +-
BUILD/Languages/chinese_simple.lng | 94 +-
BUILD/Languages/chinese_traditional.lng | 58 +-
BUILD/Languages/czech.lng | 60 +-
BUILD/Languages/dutch.lng | 48 +-
BUILD/Languages/english_uk.lng | 54 +-
BUILD/Languages/finnish.lng | 48 +-
BUILD/Languages/french.lng | 48 +-
BUILD/Languages/german.lng | 40 +-
BUILD/Languages/hebrew.lng | 48 +-
BUILD/Languages/hungarian.lng | 54 +-
BUILD/Languages/italian.lng | 92 +-
BUILD/Languages/japanese.lng | 48 +-
BUILD/Languages/polish.lng | 56 +-
BUILD/Languages/portuguese.lng | 48 +-
BUILD/Languages/portuguese_br.lng | 56 +-
BUILD/Languages/romanian.lng | 56 +-
BUILD/Languages/russian.lng | 120 +-
BUILD/Languages/slovenian.lng | 54 +-
BUILD/Languages/spanish.lng | 48 +-
BUILD/Languages/swedish.lng | 48 +-
BUILD/Languages/turkish.lng | 46 +-
BUILD/Resources.dat | Bin 296154 -> 296186 bytes
Cleanup.cmd | 2 +
FreeFileSync - wxWidgets v2.9.1 Beta.vcxproj | 310 ++
FreeFileSync.cbp | 206 +-
FreeFileSync.vcxproj | 121 +-
Makefile | 82 +-
RealtimeSync/RealtimeSync.cbp | 84 +-
RealtimeSync/RealtimeSync.vcxproj | 81 +-
RealtimeSync/application.cpp | 16 +-
RealtimeSync/functions.cpp | 10 +-
RealtimeSync/functions.h | 2 +-
RealtimeSync/guiGenerated.cpp | 246 --
RealtimeSync/guiGenerated.h | 110 -
RealtimeSync/gui_generated.cpp | 246 ++
RealtimeSync/gui_generated.h | 110 +
RealtimeSync/mainDialog.cpp | 459 ---
RealtimeSync/mainDialog.h | 75 -
RealtimeSync/main_dlg.cpp | 459 +++
RealtimeSync/main_dlg.h | 75 +
RealtimeSync/makefile | 43 +-
RealtimeSync/notify.cpp | 268 ++
RealtimeSync/notify.h | 40 +
RealtimeSync/pch.h | 6 +-
RealtimeSync/resources.cpp | 8 +-
RealtimeSync/trayMenu.cpp | 282 --
RealtimeSync/trayMenu.h | 26 -
RealtimeSync/tray_menu.cpp | 282 ++
RealtimeSync/tray_menu.h | 26 +
RealtimeSync/watcher.cpp | 372 +-
RealtimeSync/watcher.h | 4 +-
RealtimeSync/xmlFreeFileSync.cpp | 106 -
RealtimeSync/xmlFreeFileSync.h | 22 -
RealtimeSync/xmlProcessing.cpp | 91 -
RealtimeSync/xmlProcessing.h | 29 -
RealtimeSync/xml_ffs.cpp | 104 +
RealtimeSync/xml_ffs.h | 22 +
RealtimeSync/xml_proc.cpp | 91 +
RealtimeSync/xml_proc.h | 29 +
algorithm.cpp | 107 +-
algorithm.h | 4 +-
comparison.cpp | 296 +-
comparison.h | 15 +-
fileHierarchy.cpp | 205 --
fileHierarchy.h | 1490 --------
file_hierarchy.cpp | 205 ++
file_hierarchy.h | 1500 ++++++++
library/CustomGrid.cpp | 2104 -----------
library/CustomGrid.h | 356 --
library/binary.cpp | 8 +-
library/binary.h | 4 +-
library/custom_grid.cpp | 2104 +++++++++++
library/custom_grid.h | 356 ++
library/dbFile.cpp | 462 ---
library/dbFile.h | 26 -
library/db_file.cpp | 486 +++
library/db_file.h | 26 +
library/detectRenaming.cpp | 285 --
library/detectRenaming.h | 26 -
library/detect_renaming.cpp | 285 ++
library/detect_renaming.h | 26 +
library/dir_lock.cpp | 448 +++
library/dir_lock.h | 35 +
library/errorLogging.cpp | 63 -
library/errorLogging.h | 46 -
library/error_log.cpp | 63 +
library/error_log.h | 46 +
library/filter.cpp | 38 +-
library/filter.h | 2 +-
library/iconBuffer.cpp | 484 ---
library/iconBuffer.h | 63 -
library/icon_buffer.cpp | 451 +++
library/icon_buffer.h | 62 +
library/pch.h | 9 +-
library/processXml.cpp | 1037 ------
library/processXml.h | 245 --
library/process_xml.cpp | 1137 ++++++
library/process_xml.h | 267 ++
library/resources.cpp | 10 +-
library/softFilter.cpp | 10 -
library/softFilter.h | 83 -
library/soft_filter.cpp | 10 +
library/soft_filter.h | 83 +
library/statistics.cpp | 42 +-
library/statistics.h | 2 +
library/statusHandler.cpp | 33 -
library/statusHandler.h | 105 -
library/status_handler.cpp | 33 +
library/status_handler.h | 105 +
resource.rc | 2 +-
shared/IFileOperation/FileOperation_Vista.vcxproj | 6 +-
shared/IFileOperation/dll_main.cpp | 25 +
shared/IFileOperation/dllmain.cpp | 27 -
shared/IFileOperation/fileOp.cpp | 266 --
shared/IFileOperation/fileOp.h | 47 -
shared/IFileOperation/file_op.cpp | 229 ++
shared/IFileOperation/file_op.h | 47 +
shared/ShadowCopy/Shadow_2003.vcxproj | 2 +-
shared/ShadowCopy/Shadow_XP.vcxproj | 2 +-
shared/ShadowCopy/dll_main.cpp | 25 +
shared/ShadowCopy/dllmain.cpp | 27 -
shared/ShadowCopy/shadow.cpp | 139 +-
shared/ShadowCopy/shadow.h | 2 +-
shared/Taskbar_Seven/Taskbar_Seven.vcxproj | 2 +-
shared/Taskbar_Seven/dll_main.cpp | 25 +
shared/Taskbar_Seven/dllmain.cpp | 27 -
shared/Taskbar_Seven/taskbar.cpp | 30 +-
shared/appMain.cpp | 29 -
shared/appMain.h | 27 -
shared/app_main.cpp | 29 +
shared/app_main.h | 27 +
shared/assert_static.h | 37 +
shared/buildInfo.h | 18 -
shared/build_info.h | 18 +
shared/checkExist.cpp | 54 -
shared/checkExist.h | 19 -
shared/check_exist.cpp | 83 +
shared/check_exist.h | 25 +
shared/com_error.h | 77 +
shared/com_ptr.h | 186 +
shared/com_util.h | 155 +
shared/customButton.cpp | 308 --
shared/customButton.h | 42 -
shared/customComboBox.cpp | 82 -
shared/customComboBox.h | 35 -
shared/customTooltip.cpp | 101 -
shared/customTooltip.h | 27 -
shared/custom_button.cpp | 308 ++
shared/custom_button.h | 42 +
shared/custom_combo_box.cpp | 82 +
shared/custom_combo_box.h | 35 +
shared/custom_tooltip.cpp | 101 +
shared/custom_tooltip.h | 27 +
shared/debugNew.cpp | 59 -
shared/debugNew.h | 95 -
shared/debug_new.cpp | 59 +
shared/debug_new.h | 95 +
shared/dllLoader.cpp | 61 -
shared/dllLoader.h | 47 -
shared/dll_loader.cpp | 61 +
shared/dll_loader.h | 47 +
shared/dragAndDrop.cpp | 215 --
shared/dragAndDrop.h | 69 -
shared/drag_n_drop.cpp | 219 ++
shared/drag_n_drop.h | 70 +
shared/fileError.h | 33 -
shared/fileHandling.cpp | 1584 ---------
shared/fileHandling.h | 101 -
shared/fileID.cpp | 74 -
shared/fileID.h | 200 --
shared/fileIO.cpp | 181 -
shared/fileIO.h | 98 -
shared/fileTraverser.cpp | 421 ---
shared/fileTraverser.h | 67 -
shared/file_error.h | 40 +
shared/file_handling.cpp | 1855 ++++++++++
shared/file_handling.h | 105 +
shared/file_id.cpp | 74 +
shared/file_id.h | 200 ++
shared/file_io.cpp | 195 ++
shared/file_io.h | 98 +
shared/file_traverser.cpp | 421 +++
shared/file_traverser.h | 67 +
shared/globalFunctions.cpp | 93 -
shared/globalFunctions.h | 239 --
shared/global_func.cpp | 93 +
shared/global_func.h | 239 ++
shared/guid.cpp | 18 +-
shared/guid.h | 3 +-
shared/helpProvider.cpp | 46 -
shared/helpProvider.h | 17 -
shared/help_provider.cpp | 46 +
shared/help_provider.h | 17 +
shared/localization.cpp | 24 +-
shared/localization.h | 2 +-
shared/lock.cpp | 8 +-
shared/longPathPrefix.cpp | 61 -
shared/longPathPrefix.h | 30 -
shared/long_path_prefix.cpp | 61 +
shared/long_path_prefix.h | 30 +
shared/parallelCall.cpp | 159 -
shared/parallelCall.h | 34 -
shared/perf.h | 42 +
shared/recycler.cpp | 42 +-
shared/recycler.h | 4 +-
shared/serialize.cpp | 6 +-
shared/serialize.h | 4 +-
shared/shadow.cpp | 204 +-
shared/shadow.h | 22 +-
shared/signal_processing.h | 166 +
shared/standardPaths.cpp | 86 -
shared/standardPaths.h | 26 -
shared/standard_paths.cpp | 86 +
shared/standard_paths.h | 26 +
shared/staticAssert.h | 24 -
shared/stringConv.h | 110 -
shared/string_conv.h | 110 +
shared/systemConstants.h | 28 -
shared/systemFunctions.cpp | 45 -
shared/systemFunctions.h | 24 -
shared/system_constants.h | 28 +
shared/system_func.cpp | 49 +
shared/system_func.h | 24 +
shared/taskbar.cpp | 28 +-
shared/taskbar.h | 2 +-
shared/toggleButton.cpp | 50 -
shared/toggleButton.h | 49 -
shared/toggle_button.cpp | 50 +
shared/toggle_button.h | 49 +
shared/util.cpp | 42 +-
shared/util.h | 12 +-
shared/xmlBase.cpp | 400 ---
shared/xmlBase.h | 210 --
shared/xmlError.h | 41 -
shared/xml_base.cpp | 400 +++
shared/xml_base.h | 210 ++
shared/xml_error.h | 41 +
shared/zstring.cpp | 36 +-
shared/zstring.h | 55 +-
structures.cpp | 72 +-
structures.h | 40 +-
synchronization.cpp | 285 +-
synchronization.h | 10 +-
ui/MainDialog.cpp | 3804 --------------------
ui/MainDialog.h | 337 --
ui/SmallDialogs.cpp | 1026 ------
ui/SmallDialogs.h | 59 -
ui/batchConfig.cpp | 801 -----
ui/batchConfig.h | 96 -
ui/batchStatusHandler.cpp | 390 ---
ui/batchStatusHandler.h | 57 -
ui/batch_config.cpp | 840 +++++
ui/batch_config.h | 96 +
ui/batch_status_handler.cpp | 390 +++
ui/batch_status_handler.h | 57 +
ui/checkVersion.cpp | 162 -
ui/checkVersion.h | 18 -
ui/check_version.cpp | 174 +
ui/check_version.h | 18 +
ui/folderPair.h | 206 --
ui/folder_pair.h | 206 ++
ui/gridView.cpp | 570 ---
ui/gridView.h | 237 --
ui/grid_view.cpp | 570 +++
ui/grid_view.h | 237 ++
ui/guiGenerated.cpp | 3768 --------------------
ui/guiGenerated.h | 1443 --------
ui/guiStatusHandler.cpp | 397 ---
ui/guiStatusHandler.h | 73 -
ui/gui_generated.cpp | 3782 ++++++++++++++++++++
ui/gui_generated.h | 1042 ++++++
ui/gui_status_handler.cpp | 397 +++
ui/gui_status_handler.h | 73 +
ui/isNullFilter.h | 24 -
ui/is_null_filter.h | 24 +
ui/main_dlg.cpp | 3852 +++++++++++++++++++++
ui/main_dlg.h | 337 ++
ui/messagePopup.cpp | 188 -
ui/messagePopup.h | 78 -
ui/mouseMoveWindow.cpp | 26 -
ui/mouseMoveWindow.h | 36 -
ui/mouse_move_dlg.cpp | 26 +
ui/mouse_move_dlg.h | 36 +
ui/msg_popup.cpp | 188 +
ui/msg_popup.h | 78 +
ui/progressIndicator.cpp | 970 ------
ui/progressIndicator.h | 77 -
ui/progress_indicator.cpp | 970 ++++++
ui/progress_indicator.h | 77 +
ui/search.cpp | 6 +-
ui/search.h | 2 +-
ui/small_dlgs.cpp | 1028 ++++++
ui/small_dlgs.h | 59 +
ui/sorting.h | 48 +-
ui/switchToGui.cpp | 27 -
ui/switchToGui.h | 29 -
ui/switch_to_gui.cpp | 27 +
ui/switch_to_gui.h | 29 +
ui/syncConfig.cpp | 477 ---
ui/syncConfig.h | 99 -
ui/sync_cfg.cpp | 477 +++
ui/sync_cfg.h | 99 +
ui/trayIcon.cpp | 213 --
ui/trayIcon.h | 34 -
ui/tray_icon.cpp | 213 ++
ui/tray_icon.h | 34 +
version/version.h | 4 +-
version/version.rc | 4 +-
319 files changed, 34338 insertions(+), 32546 deletions(-)
create mode 100644 BUILD/Help/html/Unbenannt 1.odf
create mode 100644 FreeFileSync - wxWidgets v2.9.1 Beta.vcxproj
delete mode 100644 RealtimeSync/guiGenerated.cpp
delete mode 100644 RealtimeSync/guiGenerated.h
create mode 100644 RealtimeSync/gui_generated.cpp
create mode 100644 RealtimeSync/gui_generated.h
delete mode 100644 RealtimeSync/mainDialog.cpp
delete mode 100644 RealtimeSync/mainDialog.h
create mode 100644 RealtimeSync/main_dlg.cpp
create mode 100644 RealtimeSync/main_dlg.h
create mode 100644 RealtimeSync/notify.cpp
create mode 100644 RealtimeSync/notify.h
delete mode 100644 RealtimeSync/trayMenu.cpp
delete mode 100644 RealtimeSync/trayMenu.h
create mode 100644 RealtimeSync/tray_menu.cpp
create mode 100644 RealtimeSync/tray_menu.h
delete mode 100644 RealtimeSync/xmlFreeFileSync.cpp
delete mode 100644 RealtimeSync/xmlFreeFileSync.h
delete mode 100644 RealtimeSync/xmlProcessing.cpp
delete mode 100644 RealtimeSync/xmlProcessing.h
create mode 100644 RealtimeSync/xml_ffs.cpp
create mode 100644 RealtimeSync/xml_ffs.h
create mode 100644 RealtimeSync/xml_proc.cpp
create mode 100644 RealtimeSync/xml_proc.h
delete mode 100644 fileHierarchy.cpp
delete mode 100644 fileHierarchy.h
create mode 100644 file_hierarchy.cpp
create mode 100644 file_hierarchy.h
delete mode 100644 library/CustomGrid.cpp
delete mode 100644 library/CustomGrid.h
create mode 100644 library/custom_grid.cpp
create mode 100644 library/custom_grid.h
delete mode 100644 library/dbFile.cpp
delete mode 100644 library/dbFile.h
create mode 100644 library/db_file.cpp
create mode 100644 library/db_file.h
delete mode 100644 library/detectRenaming.cpp
delete mode 100644 library/detectRenaming.h
create mode 100644 library/detect_renaming.cpp
create mode 100644 library/detect_renaming.h
create mode 100644 library/dir_lock.cpp
create mode 100644 library/dir_lock.h
delete mode 100644 library/errorLogging.cpp
delete mode 100644 library/errorLogging.h
create mode 100644 library/error_log.cpp
create mode 100644 library/error_log.h
delete mode 100644 library/iconBuffer.cpp
delete mode 100644 library/iconBuffer.h
create mode 100644 library/icon_buffer.cpp
create mode 100644 library/icon_buffer.h
delete mode 100644 library/processXml.cpp
delete mode 100644 library/processXml.h
create mode 100644 library/process_xml.cpp
create mode 100644 library/process_xml.h
delete mode 100644 library/softFilter.cpp
delete mode 100644 library/softFilter.h
create mode 100644 library/soft_filter.cpp
create mode 100644 library/soft_filter.h
delete mode 100644 library/statusHandler.cpp
delete mode 100644 library/statusHandler.h
create mode 100644 library/status_handler.cpp
create mode 100644 library/status_handler.h
create mode 100644 shared/IFileOperation/dll_main.cpp
delete mode 100644 shared/IFileOperation/dllmain.cpp
delete mode 100644 shared/IFileOperation/fileOp.cpp
delete mode 100644 shared/IFileOperation/fileOp.h
create mode 100644 shared/IFileOperation/file_op.cpp
create mode 100644 shared/IFileOperation/file_op.h
create mode 100644 shared/ShadowCopy/dll_main.cpp
delete mode 100644 shared/ShadowCopy/dllmain.cpp
create mode 100644 shared/Taskbar_Seven/dll_main.cpp
delete mode 100644 shared/Taskbar_Seven/dllmain.cpp
delete mode 100644 shared/appMain.cpp
delete mode 100644 shared/appMain.h
create mode 100644 shared/app_main.cpp
create mode 100644 shared/app_main.h
create mode 100644 shared/assert_static.h
delete mode 100644 shared/buildInfo.h
create mode 100644 shared/build_info.h
delete mode 100644 shared/checkExist.cpp
delete mode 100644 shared/checkExist.h
create mode 100644 shared/check_exist.cpp
create mode 100644 shared/check_exist.h
create mode 100644 shared/com_error.h
create mode 100644 shared/com_ptr.h
create mode 100644 shared/com_util.h
delete mode 100644 shared/customButton.cpp
delete mode 100644 shared/customButton.h
delete mode 100644 shared/customComboBox.cpp
delete mode 100644 shared/customComboBox.h
delete mode 100644 shared/customTooltip.cpp
delete mode 100644 shared/customTooltip.h
create mode 100644 shared/custom_button.cpp
create mode 100644 shared/custom_button.h
create mode 100644 shared/custom_combo_box.cpp
create mode 100644 shared/custom_combo_box.h
create mode 100644 shared/custom_tooltip.cpp
create mode 100644 shared/custom_tooltip.h
delete mode 100644 shared/debugNew.cpp
delete mode 100644 shared/debugNew.h
create mode 100644 shared/debug_new.cpp
create mode 100644 shared/debug_new.h
delete mode 100644 shared/dllLoader.cpp
delete mode 100644 shared/dllLoader.h
create mode 100644 shared/dll_loader.cpp
create mode 100644 shared/dll_loader.h
delete mode 100644 shared/dragAndDrop.cpp
delete mode 100644 shared/dragAndDrop.h
create mode 100644 shared/drag_n_drop.cpp
create mode 100644 shared/drag_n_drop.h
delete mode 100644 shared/fileError.h
delete mode 100644 shared/fileHandling.cpp
delete mode 100644 shared/fileHandling.h
delete mode 100644 shared/fileID.cpp
delete mode 100644 shared/fileID.h
delete mode 100644 shared/fileIO.cpp
delete mode 100644 shared/fileIO.h
delete mode 100644 shared/fileTraverser.cpp
delete mode 100644 shared/fileTraverser.h
create mode 100644 shared/file_error.h
create mode 100644 shared/file_handling.cpp
create mode 100644 shared/file_handling.h
create mode 100644 shared/file_id.cpp
create mode 100644 shared/file_id.h
create mode 100644 shared/file_io.cpp
create mode 100644 shared/file_io.h
create mode 100644 shared/file_traverser.cpp
create mode 100644 shared/file_traverser.h
delete mode 100644 shared/globalFunctions.cpp
delete mode 100644 shared/globalFunctions.h
create mode 100644 shared/global_func.cpp
create mode 100644 shared/global_func.h
delete mode 100644 shared/helpProvider.cpp
delete mode 100644 shared/helpProvider.h
create mode 100644 shared/help_provider.cpp
create mode 100644 shared/help_provider.h
delete mode 100644 shared/longPathPrefix.cpp
delete mode 100644 shared/longPathPrefix.h
create mode 100644 shared/long_path_prefix.cpp
create mode 100644 shared/long_path_prefix.h
delete mode 100644 shared/parallelCall.cpp
delete mode 100644 shared/parallelCall.h
create mode 100644 shared/perf.h
create mode 100644 shared/signal_processing.h
delete mode 100644 shared/standardPaths.cpp
delete mode 100644 shared/standardPaths.h
create mode 100644 shared/standard_paths.cpp
create mode 100644 shared/standard_paths.h
delete mode 100644 shared/staticAssert.h
delete mode 100644 shared/stringConv.h
create mode 100644 shared/string_conv.h
delete mode 100644 shared/systemConstants.h
delete mode 100644 shared/systemFunctions.cpp
delete mode 100644 shared/systemFunctions.h
create mode 100644 shared/system_constants.h
create mode 100644 shared/system_func.cpp
create mode 100644 shared/system_func.h
delete mode 100644 shared/toggleButton.cpp
delete mode 100644 shared/toggleButton.h
create mode 100644 shared/toggle_button.cpp
create mode 100644 shared/toggle_button.h
delete mode 100644 shared/xmlBase.cpp
delete mode 100644 shared/xmlBase.h
delete mode 100644 shared/xmlError.h
create mode 100644 shared/xml_base.cpp
create mode 100644 shared/xml_base.h
create mode 100644 shared/xml_error.h
delete mode 100644 ui/MainDialog.cpp
delete mode 100644 ui/MainDialog.h
delete mode 100644 ui/SmallDialogs.cpp
delete mode 100644 ui/SmallDialogs.h
delete mode 100644 ui/batchConfig.cpp
delete mode 100644 ui/batchConfig.h
delete mode 100644 ui/batchStatusHandler.cpp
delete mode 100644 ui/batchStatusHandler.h
create mode 100644 ui/batch_config.cpp
create mode 100644 ui/batch_config.h
create mode 100644 ui/batch_status_handler.cpp
create mode 100644 ui/batch_status_handler.h
delete mode 100644 ui/checkVersion.cpp
delete mode 100644 ui/checkVersion.h
create mode 100644 ui/check_version.cpp
create mode 100644 ui/check_version.h
delete mode 100644 ui/folderPair.h
create mode 100644 ui/folder_pair.h
delete mode 100644 ui/gridView.cpp
delete mode 100644 ui/gridView.h
create mode 100644 ui/grid_view.cpp
create mode 100644 ui/grid_view.h
delete mode 100644 ui/guiGenerated.cpp
delete mode 100644 ui/guiGenerated.h
delete mode 100644 ui/guiStatusHandler.cpp
delete mode 100644 ui/guiStatusHandler.h
create mode 100644 ui/gui_generated.cpp
create mode 100644 ui/gui_generated.h
create mode 100644 ui/gui_status_handler.cpp
create mode 100644 ui/gui_status_handler.h
delete mode 100644 ui/isNullFilter.h
create mode 100644 ui/is_null_filter.h
create mode 100644 ui/main_dlg.cpp
create mode 100644 ui/main_dlg.h
delete mode 100644 ui/messagePopup.cpp
delete mode 100644 ui/messagePopup.h
delete mode 100644 ui/mouseMoveWindow.cpp
delete mode 100644 ui/mouseMoveWindow.h
create mode 100644 ui/mouse_move_dlg.cpp
create mode 100644 ui/mouse_move_dlg.h
create mode 100644 ui/msg_popup.cpp
create mode 100644 ui/msg_popup.h
delete mode 100644 ui/progressIndicator.cpp
delete mode 100644 ui/progressIndicator.h
create mode 100644 ui/progress_indicator.cpp
create mode 100644 ui/progress_indicator.h
create mode 100644 ui/small_dlgs.cpp
create mode 100644 ui/small_dlgs.h
delete mode 100644 ui/switchToGui.cpp
delete mode 100644 ui/switchToGui.h
create mode 100644 ui/switch_to_gui.cpp
create mode 100644 ui/switch_to_gui.h
delete mode 100644 ui/syncConfig.cpp
delete mode 100644 ui/syncConfig.h
create mode 100644 ui/sync_cfg.cpp
create mode 100644 ui/sync_cfg.h
delete mode 100644 ui/trayIcon.cpp
delete mode 100644 ui/trayIcon.h
create mode 100644 ui/tray_icon.cpp
create mode 100644 ui/tray_icon.h
diff --git a/Application.h b/Application.h
index cf69890d..bfc4a45f 100644
--- a/Application.h
+++ b/Application.h
@@ -8,7 +8,7 @@
#define FREEFILESYNCAPP_H
#include
-#include "library/processXml.h"
+#include "library/process_xml.h"
class Application : public wxApp
diff --git a/BUILD/Changelog.txt b/BUILD/Changelog.txt
index a896ab4a..693d96fc 100644
--- a/BUILD/Changelog.txt
+++ b/BUILD/Changelog.txt
@@ -2,6 +2,25 @@
|FreeFileSync|
--------------
+Changelog v3.9
+--------------
+Advanced locking strategy to allow multiple processes synchronize the same directories (e.g. via network share)
+Merge multiple *.ffs_batch, *.ffs_gui files or combinations of both via drag & drop
+Copy file and folder permissions (requires admin rights):
+ - Windows: owner, group, DACL, SACL
+ - Linux: owner, group, permissions
+ - correctly handle Symbolic Links
+ - new option in global settings
+Compare by content evaluates Symbolic Links
+32-Bit build compiled with MinGW/GCC to preserve Windows 2000 compatibility
+RealtimeSync: Handle requests for device removal (USB stick) while monitoring
+Sort by filesize: group symlinks before directories
+Added macros %week%, %month%, %year% for creating time-stamped directories
+Touch database file when changes occured only
+Moved settings "file time tolerance" and "verify copied files" to GlobalSettings.xml
+Updated translation files
+
+
Changelog v3.8
--------------
New options handling Symlinks: ignore/direct/follow => warning: new database format for mode
diff --git a/BUILD/FreeFileSync.chm b/BUILD/FreeFileSync.chm
index 0772a6ac..cfcf6752 100644
Binary files a/BUILD/FreeFileSync.chm and b/BUILD/FreeFileSync.chm differ
diff --git a/BUILD/Help/Table of Contents.hhc b/BUILD/Help/Table of Contents.hhc
index e57b8399..35ad8d46 100644
--- a/BUILD/Help/Table of Contents.hhc
+++ b/BUILD/Help/Table of Contents.hhc
@@ -53,7 +53,7 @@
Copy
file and folder create/access/modification times when synchronizing
+ Advanced
+ locking strategy to allow multiple synchronization processes (e.g.
+ multiple writers, same network share)
diff --git a/Application.cpp b/Application.cpp
index d0a05124..120bd567 100644
--- a/Application.cpp
+++ b/Application.cpp
@@ -5,36 +5,37 @@
// **************************************************************************
//
#include "application.h"
-#include "ui/mainDialog.h"
+#include "ui/main_dlg.h"
#include
#include "comparison.h"
#include "algorithm.h"
#include "synchronization.h"
#include
-#include "ui/batchStatusHandler.h"
-#include "ui/checkVersion.h"
+#include "ui/batch_status_handler.h"
+#include "ui/check_version.h"
#include "library/filter.h"
#include
-#include "shared/xmlBase.h"
+#include "shared/xml_base.h"
#include "library/resources.h"
-#include "ui/switchToGui.h"
-#include "shared/standardPaths.h"
+#include "ui/switch_to_gui.h"
+#include "shared/standard_paths.h"
#include "shared/localization.h"
-#include "shared/appMain.h"
+#include "shared/app_main.h"
#include
-#include "shared/fileHandling.h"
-#include "shared/stringConv.h"
+#include "shared/file_handling.h"
+#include "shared/string_conv.h"
#ifdef FFS_LINUX
#include
#endif
-using FreeFileSync::CustomLocale;
-using FreeFileSync::SwitchToGui;
+using ffs3::CustomLocale;
+using ffs3::SwitchToGui;
IMPLEMENT_APP(Application)
+
bool Application::OnInit()
{
returnValue = 0;
@@ -50,7 +51,7 @@ bool Application::OnInit()
void Application::OnStartApplication(wxIdleEvent&)
{
- using namespace FreeFileSync;
+ using namespace ffs3;
Disconnect(wxEVT_IDLE, wxIdleEventHandler(Application::OnStartApplication), NULL, this);
@@ -63,7 +64,7 @@ void Application::OnStartApplication(wxIdleEvent&)
~HandleAppExit()
{
- if (!FreeFileSync::AppMainWindow::mainWindowWasSet())
+ if (!ffs3::AppMainWindow::mainWindowWasSet())
wxTheApp->ExitMainLoop(); //quit application, if no main window was set (batch silent mode)
}
@@ -74,7 +75,7 @@ void Application::OnStartApplication(wxIdleEvent&)
SetAppName(wxT("FreeFileSync"));
#ifdef FFS_LINUX
- ::gtk_rc_parse(FreeFileSync::wxToZ(FreeFileSync::getResourceDir()) + "styles.rc"); //remove inner border from bitmap buttons
+ ::gtk_rc_parse(ffs3::wxToZ(ffs3::getResourceDir()) + "styles.rc"); //remove inner border from bitmap buttons
#endif
@@ -104,16 +105,16 @@ void Application::OnStartApplication(wxIdleEvent&)
try //load global settings from XML
{
if (fileExists(wxToZ(xmlAccess::getGlobalConfigFile())))
- xmlAccess::readGlobalSettings(globalSettings);
+ xmlAccess::readConfig(globalSettings);
//else: globalSettings already has default values
}
catch (const xmlAccess::XmlError& error)
{
//show messagebox and continue
if (error.getSeverity() == xmlAccess::XmlError::WARNING)
; //wxMessageBox(error.show(), _("Warning"), wxOK | wxICON_WARNING); -> ignore parsing errors: should be migration problems only *cross-fingers*
else
- wxMessageBox(error.show(), _("Error"), wxOK | wxICON_ERROR);
+ wxMessageBox(error.msg(), _("Error"), wxOK | wxICON_ERROR);
}
//set program language
@@ -161,10 +162,10 @@ int Application::OnRun()
catch (const std::exception& e) //catch all STL exceptions
{
//unfortunately it's not always possible to display a message box in this erroneous situation, however (non-stream) file output always works!
- wxFile safeOutput(FreeFileSync::getConfigDir() + wxT("LastError.txt"), wxFile::write);
+ wxFile safeOutput(ffs3::getConfigDir() + wxT("LastError.txt"), wxFile::write);
safeOutput.Write(wxString::FromAscii(e.what()));
- wxMessageBox(wxString::FromAscii(e.what()), _("An exception occured!"), wxOK | wxICON_ERROR);
+ wxMessageBox(wxString::FromAscii(e.what()), _("An exception occurred!"), wxOK | wxICON_ERROR);
return -9;
}
@@ -179,11 +180,11 @@ int Application::OnExit()
try //save global settings to XML
{
- xmlAccess::writeGlobalSettings(globalSettings);
+ xmlAccess::writeConfig(globalSettings);
}
catch (const xmlAccess::XmlError& error)
{
- wxMessageBox(error.show(), _("Error"), wxOK | wxICON_ERROR);
+ wxMessageBox(error.msg(), _("Error"), wxOK | wxICON_ERROR);
}
return 0;
@@ -205,18 +206,18 @@ void Application::runBatchMode(const wxString& filename, xmlAccess::XmlGlobalSet
xmlAccess::XmlBatchConfig batchCfg; //structure to receive gui settings
try
{
- xmlAccess::readBatchConfig(filename, batchCfg);
+ xmlAccess::readConfig(filename, batchCfg);
}
catch (const xmlAccess::XmlError& error)
{
- wxMessageBox(error.show(), _("Error"), wxOK | wxICON_ERROR);
+ wxMessageBox(error.msg(), _("Error"), wxOK | wxICON_ERROR);
return;
}
//all settings have been read successfully...
//regular check for program updates -> disabled for batch
//if (!batchCfg.silent)
- // FreeFileSync::checkForUpdatePeriodically(globSettings.lastUpdateCheck);
+ // ffs3::checkForUpdatePeriodically(globSettings.lastUpdateCheck);
try //begin of synchronization process (all in one try-catch block)
{
@@ -230,14 +231,14 @@ void Application::runBatchMode(const wxString& filename, xmlAccess::XmlGlobalSet
statusHandler.reset(new BatchStatusHandler(false, filename, NULL, batchCfg.handleError, switchBatchToGui, returnValue));
//COMPARE DIRECTORIES
- FreeFileSync::FolderComparison folderCmp;
- FreeFileSync::CompareProcess comparison(batchCfg.mainCfg.handleSymlinks,
- batchCfg.mainCfg.hidden.fileTimeTolerance,
+ ffs3::FolderComparison folderCmp;
+ ffs3::CompareProcess comparison(batchCfg.mainCfg.handleSymlinks,
+ globSettings.fileTimeTolerance,
globSettings.ignoreOneHourDiff,
globSettings.optDialogs,
statusHandler.get());
- comparison.startCompareProcess(FreeFileSync::extractCompareCfg(batchCfg.mainCfg),
+ comparison.startCompareProcess(ffs3::extractCompareCfg(batchCfg.mainCfg),
batchCfg.mainCfg.compareVar,
folderCmp);
@@ -249,23 +250,24 @@ void Application::runBatchMode(const wxString& filename, xmlAccess::XmlGlobalSet
}
//START SYNCHRONIZATION
- FreeFileSync::SyncProcess synchronization(
+ ffs3::SyncProcess synchronization(
globSettings.optDialogs,
- batchCfg.mainCfg.hidden.verifyFileCopy,
+ globSettings.verifyFileCopy,
globSettings.copyLockedFiles,
+ globSettings.copyFilePermissions,
*statusHandler);
- const std::vector syncProcessCfg = FreeFileSync::extractSyncCfg(batchCfg.mainCfg);
+ const std::vector syncProcessCfg = ffs3::extractSyncCfg(batchCfg.mainCfg);
assert(syncProcessCfg.size() == folderCmp.size());
synchronization.startSynchronizationProcess(syncProcessCfg, folderCmp);
//play (optional) sound notification after sync has completed (GUI and batch mode)
- const wxString soundFile = FreeFileSync::getResourceDir() + wxT("Sync_Complete.wav");
- if (FreeFileSync::fileExists(FreeFileSync::wxToZ(soundFile)))
+ const wxString soundFile = ffs3::getResourceDir() + wxT("Sync_Complete.wav");
+ if (ffs3::fileExists(ffs3::wxToZ(soundFile)))
wxSound::Play(soundFile, wxSOUND_ASYNC);
}
- catch (FreeFileSync::AbortThisProcess&) //exit used by statusHandler
+ catch (ffs3::AbortThisProcess&) //exit used by statusHandler
{
if (returnValue >= 0)
returnValue = -12;
@@ -104,16 +105,16 @@ void Application::OnStartApplication(wxIdleEvent&)
//show messagebox and continue
if (error.getSeverity() == xmlAccess::XmlError::WARNING)
- ; //wxMessageBox(error.show(), _("Warning"), wxOK | wxICON_WARNING); -> ignore parsing errors: should be migration problems only *cross-fingers*
+ ; //wxMessageBox(error.msg(), _("Warning"), wxOK | wxICON_WARNING); -> ignore parsing errors: should be migration problems only *cross-fingers*
else